%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Amplification Module
%%A is the variable which enables me to control the action of my script:
%if A=0 => plot the graphs of gfp in function of the time. We have 12
%graphs because we vary the initial camp concentration between 10^(-1) and
%10^(-12) mol.L-1.
%if A=1 => plot the graphs of steaday state of gfp in function of the
%initial concentration of camp
%if A=2 => we plot crpcamp function of the time
%else => we plot the surface of the evolution of the concentration of gfp 
%in function of the initial concentration of camp and arabinose
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear;

%index for the matrix

arac=1;
ca=2;
camp=3;

%synthesis rates

synt_rates=zeros(2);%mol.L-1.min-1

synt_rates(arac)=12*10^(-8);
synt_rates(ca)=2*10^(-9);

%threshold

Karac=0.3*10^(-6);%mol.L-1
Kca=0.5*10^(-5);%corresponds to the activation by arac
Kpca=0.6*10^(-6);%corresponds to the activation by crpcamp

%catalyse coefficient

kcat=6*135;%min-1

%Dissociation rates

diss_rates=zeros(2);%mol-1.L

diss_rates(camp)=10^(-5);
diss_rates(arac)=2*10^(-13);


%export/degradation rates

degr_rates=zeros(3);%min-1

degr_rates(arac)=6*10^(-3);
degr_rates(ca)=6*10^(-3);
degr_rates(camp)=2.1;

%basal coefficients

p_basal=zeros(2);%mol.L.min-1

p_basal(arac)=12*10^(-11);
p_basal(ca)=2*10^(-12);

%constant production

arabinose=10^(-4);%mol.L-1
crp=10^(-6);

%quorum sensing coefficient
eta=6*10^(-1);%min-1

%hill cooperativity

n=1.5;

tspan=[0 2000];

%initial conditions
%there is noting at the beginning

uinit=[0 0];

%boolean used to control the algorithm

A=2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Here we plot 12 graphs.                                          %
%the graph i represents the evolution in function of the time with% 
%CAMPi=10^(-i)mol.L-1                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if A==0

for i=3:8
    CAMPi=10^(-i);%initial condition for CAMP
    
    [sol_vec]=solvCamp2(tspan,uinit,diss_rates,kcat,Karac,Kca,...
    Kpca,synt_rates,p_basal,degr_rates,n,arabinose,crp,CAMPi,eta);
    
    %sol_vec is the vector of solutions
    %sol_vec(:,4) is the vector of time
    
    figure(i);
    
    aracet=sol_vec(:,arac)./(1+diss_rates(arac)/arabinose);
    
    plot(sol_vec(:,3),sol_vec(:,ca));
	title('Ca concentration VS time' );
	xlabel('time (min)');
	ylabel('Ca concentration (mol.L-1)');
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Here we plot the evolution of the steady state of gfp in function of%
%the initial concentration of camp                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

elseif A==1
    
    Mca=zeros(1101);%steady state ca vector
    Maracet=zeros(1101);%steady state arac active vector
    logCAMPi=zeros(1101);%vector of log(CAMPi)
   

m=0;
for j=1:0.01:12
   
    m=m+1;%index of the vectors
    
    CAMPi=10^(-j);%initial concentration of camp
    
    [sol_vec]=solvCamp2(tspan,uinit,diss_rates,kcat,Karac,Kca,...
    Kpca,synt_rates,p_basal,degr_rates,n,arabinose,crp,CAMPi,eta);

    aracet=sol_vec(:,arac)./(1+diss_rates(arac)/arabinose);
    
    Maracet(m)=aracet(end);
    Mca(m)=sol_vec(end,ca);
    logCAMPi(m)=10^(-j);
end


figure(1);
semilogx(logCAMPi,Mca);
title('ca concentration at t=2000min VS cAMP initial concentration');
xlabel('cAMPi concentration (mol.L-1)');
ylabel('Ca concentration (mol.L-1)');

figure(2);
semilogx(logCAMPi,Maracet);
title('aracet concentration at t=2000min VS cAMP initial concentration');
xlabel('cAMPi concentration (mol.L-1)');
ylabel('aracet concentration (mol.L-1)');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Here we just build the vector of camp and crpcamp infunction of the time% 
%we have to do it because they are not solutions of the system           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

elseif A==2

    CAMPi_v=zeros(60);%vector of initial concentration of cAMP
    crpcamp_st_st=zeros(60);%steady state vector of crpcamp
    m=1;

for j=3:0.1:8
    
    CAMPi=10^(-j);
    CAMPi_v(m)=CAMPi;
    
    [sol_vec]=solvCamp2(tspan,uinit,diss_rates,kcat,Karac,Kca,...
    Kpca,synt_rates,p_basal,degr_rates,n,arabinose,crp,CAMPi,eta);
    
    %we get the lenght of the matrix ca
    [taille_l,taille_c]=size(sol_vec(:,ca));
    
    %initialisation of the matrix camp
    camp_vec=zeros(taille_l,1);
    crpcamp_vec=zeros(taille_l,1);
    
    camp_vec=kcat*sol_vec(:,ca)/degr_rates(camp)+eta*CAMPi/degr_rates(camp);
    
    %creation of the matrix crpcamp
        crpcamp_vec=((diss_rates(camp) + camp_vec + crp)...
            - sqrt((diss_rates(camp) + camp_vec + crp).^2 -4 * camp_vec .* crp))/2;

       
        crpcamp_st_st(m)=crpcamp_vec(end);
        m=m+1;
        
end


semilogx(CAMPi_v,crpcamp_st_st);
title('crpcamp concentration VS cAMP initial concentration');
xlabel('cAMP initial concentration (mol.L-1)');
ylabel('CRP-cAMP initial concentration (mol.L-1)');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Here we plot the surface of steady state of gfp in function of the       %
%initial concentration of camp and arabinose                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

else

m1=0;
Camp=zeros(12,1);%vector of concentration of camp initial
Arabinose=zeros(12,1);%vector of concentration of arabinose initial
CaSurf=zeros(12);%steady state of gfp in function of arabinose and 
    %of campi

for i=1:12
    m1=m1+1;
    
    CAMPi=10^(-i);
    m2=0;
    
    for j=1:12
        m2=m2+1;
        
        arabinose=10^(-j);
        
        [sol_vec]=solvCamp2(tspan,uinit,diss_rates,kcat,Karac,Kca,...
    Kpca,synt_rates,p_basal,degr_rates,n,arabinose,crp,CAMPi);
        
CaSurf(m1,m2)=sol_vec(end,gfp);
        
Arabinose(m2)=-j;
    end
    
    Camp(m1)=-i;
end

surf(Arabinose,Camp,CaSurf)

title('ca concentration in function of arabinose and camp');
xlabel('arabinose');
ylabel('camp');
zlabel('ca');

end






